# holitas

una biblioteca para olitas

## cursos disponibles:

-introduccion a linux
-personalizacion
-introduccion al hacking

## instalacion

intala el paquete usando `pip3`:

```python3
pip3 install hack4u
```

## Uso basico


